==> apache-streampipes-0.95.1-source-release.zip: apache-streampipes-0.95.1/streampipes-connect-shared/src/main/java/org/apache/streampipes/connect/shared/preprocessing/SupportsNestedTransformationRule.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.connect.shared.preprocessing;

import org.apache.streampipes.connect.shared.preprocessing.transform.TransformationRule;

import java.util.List;
import java.util.Map;

public abstract class SupportsNestedTransformationRule implements TransformationRule {

  @Override
  public Map<String, Object> apply(Map<String, Object> event) {
    return applyNested(event, getEventKeys());
  }

  protected Map<String, Object> applyNested(Map<String, Object> event,
                                          List<String> eventKey) {
    if (eventKey.size() == 1) {
      applyTransformation(event, eventKey);
    } else {
      String key = eventKey.get(0);
      List<String> newKeysTmpList = eventKey.subList(1, eventKey.size());

      Map<String, Object> newSubEvent =
          applyNested((Map<String, Object>) event.get(eventKey.get(0)), newKeysTmpList);

      event.remove(key);

      if (newSubEvent != null) {
        event.put(key, newSubEvent);
      }
    }
    return event;
  }

  protected abstract List<String> getEventKeys();

  protected abstract void applyTransformation(Map<String, Object> event,
                                              List<String> eventKey);


}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/streampipes-connect-shared/src/main/java/org/apache/streampipes/connect/shared/preprocessing/SupportsNestedTransformationRule.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.connect.shared.preprocessing;

import org.apache.streampipes.extensions.api.connect.TransformationRule;

import java.util.List;
import java.util.Map;

public abstract class SupportsNestedTransformationRule implements TransformationRule {

  @Override
  public Map<String, Object> apply(Map<String, Object> event) {
    return applyNested(event, getEventKeys());
  }

  protected Map<String, Object> applyNested(Map<String, Object> event,
                                          List<String> eventKey) {
    if (eventKey.size() == 1) {
      applyTransformation(event, eventKey);
    } else {
      String key = eventKey.get(0);
      List<String> newKeysTmpList = eventKey.subList(1, eventKey.size());

      Map<String, Object> newSubEvent =
          applyNested((Map<String, Object>) event.get(eventKey.get(0)), newKeysTmpList);

      event.remove(key);

      if (newSubEvent != null) {
        event.put(key, newSubEvent);
      }
    }
    return event;
  }

  protected abstract List<String> getEventKeys();

  protected abstract void applyTransformation(Map<String, Object> event,
                                              List<String> eventKey);


}
